﻿using Newtonsoft.Json;

namespace Sample
{
    public record TokenResponse
    {
        public string access_token { get; init; }
    }

    public class BaiduChatRequest
    {
        [JsonProperty("messages")]
        public List<Message> Messages { get; set; }

        [JsonProperty("system")]
        public string System { get; set; }

        [JsonProperty("temperature")]
        public float Temperature { get; set; }

        [JsonProperty("top_p")]
        public float TopP { get; set; }

        [JsonProperty("frequency_penalty")]
        public float FrequencyPenalty { get; set; }

        [JsonProperty("presence_penalty")]
        public float PresencePenalty { get; set; }

        [JsonProperty("penalty_score")]
        public float PenaltyScore { get; set; }

        [JsonProperty("disable_search")]
        public bool DisableSearch { get; set; } = true;

        [JsonProperty("enable_citation")]
        public bool EnableCitation { get; set; } = false;

        [JsonProperty("collapsed")]
        public bool Collapsed { get; set; } = true;

        [JsonProperty("stream")]
        public bool Stream { get; set; }

        //CompletionRequest to BaiduChatRequest
        public static BaiduChatRequest ToModel(CompletionRequest completionRequest)
        {
            var system = completionRequest.messages.FirstOrDefault(x => x.role == "system");
            if (system != null)
            {
                completionRequest.messages.Remove(system);
            }
            return new BaiduChatRequest
            {
                Messages = completionRequest.messages,
                PenaltyScore = 1.0f,
                Temperature = 0.9f,
                TopP = completionRequest.top_p,
                FrequencyPenalty = completionRequest.frequency_penalty,
                PresencePenalty = completionRequest.presence_penalty,
                Stream = completionRequest.stream,
                System = system?.content
            };
        }
    }


    public record BaiduAIResponse
    {
        /// <summary>
        ///  The error code.
        /// </summary>
        public int error_code { get; set; }

        /// <summary>
        /// The response text.
        /// </summary>
        public string result { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public bool is_end { get; set; }
    }
}
