using Microsoft.AspNetCore.Mvc;
using System.Text;

namespace Sample.Controllers
{
    [ApiController]
    [Route("[controller]")]
    public class AIController : ControllerBase
    {
        private readonly BaiduApiService _baiduApiService;
        public AIController(BaiduApiService baiduApiService)
        {
            _baiduApiService = baiduApiService;
        }
        /// <summary>
        /// This is a proxy method to call the AI service.
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        [HttpPost, Route("proxy")]
        public async Task Proxy([FromBody] CompletionRequest request)
        {
            if (request.stream)
            {
                var resultStream = _baiduApiService.CallChatApiStreamAsync(BaiduChatRequest.ToModel(request), request.model);
                // 设置响应头
                Response.ContentType = "text/event-stream";

                // 将异步可枚举序列转换成流
                await foreach (var str in resultStream)
                {
                    await Response.Body.WriteAsync(Encoding.UTF8.GetBytes(str));
                    await Response.Body.FlushAsync();
                }
            }
            else
            {
                var response = await _baiduApiService.CallChatApiAsync(BaiduChatRequest.ToModel(request), request.model);
                // 设置响应头
                Response.ContentType = "application/json";
                await Response.Body.WriteAsync(Encoding.UTF8.GetBytes(CompletionResponse.ToResponseJson(response)));
                await Response.Body.FlushAsync();
            }
        }
    }
}
